@@ -1,6 +1,6 @@
 package AnyEvent::FTP::Client;
 
-use v5.10;
+use 5.010;
 use Moo;
 use warnings NONFATAL => 'all';
 use AnyEvent;
@@ -10,7 +10,7 @@ use Carp qw( croak );
 use Socket qw( unpack_sockaddr_in inet_ntoa );
 
 # ABSTRACT: Simple asynchronous ftp client
-our $VERSION = '0.06'; # VERSION
+our $VERSION = '0.07'; # VERSION
 
 
 with 'AnyEvent::FTP::Role::Event';
@@ -339,7 +339,7 @@ AnyEvent::FTP::Client - Simple asynchronous ftp client
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 SYNOPSIS
 
@@ -613,6 +613,16 @@ server.
 
  $client->retr('foo.txt', 'foo.txt');
 
+=item subroutine reference / callback reference
+
+The contents of the file will be passed to the callback as they are received.
+
+ $client->retr('foo.txt', sub {
+     my ($data) = @_;
+     # Do something with $data
+   },
+ );
+
 =back
 
 In order to resume a transfer, you need to include the C<restart> option after the 
@@ -900,7 +910,7 @@ FTP commands and their responses as they happen.
  use strict;
  use warnings;
  use autodie;
- use v5.10;
+ use 5.010;
  use AnyEvent::FTP::Client;
  use URI;
  use URI::file;
@@ -1043,7 +1053,7 @@ to see the long form of the file listing.
 
  use strict;
  use warnings;
- use v5.10;
+ use 5.010;
  use URI;
  use AnyEvent::FTP::Client;
  use Term::Prompt qw( prompt );
@@ -1114,7 +1124,7 @@ and a remote FTP URL.
  use strict;
  use warnings;
  use autodie;
- use v5.10;
+ use 5.010;
  use AnyEvent::FTP::Client;
  use URI;
  use URI::file;
@@ -1252,9 +1262,9 @@ L<AnyEvent::FTP::Server>
 
 =head1 AUTHOR
 
-author: Graham Ollis <plicease@cpan.org>
+Author: Graham Ollis E<lt>plicease@cpan.orgE<gt>
 
-contributors:
+Contributors:
 
 Ryo Okamoto
 
