@@ -2,13 +2,13 @@ package AnyEvent::FTP::Client::Role::ResponseBuffer;
 
 use strict;
 use warnings;
-use v5.10;
+use 5.010;
 use Moo::Role;
 use warnings NONFATAL => 'all';
 use AnyEvent::FTP::Client::Response;
 
 # ABSTRACT: Response buffer role for asynchronous ftp client
-our $VERSION = '0.06'; # VERSION
+our $VERSION = '0.07'; # VERSION
 
 
 sub on_next_response
@@ -69,7 +69,7 @@ AnyEvent::FTP::Client::Role::ResponseBuffer - Response buffer role for asynchron
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 DESCRIPTION
 
@@ -77,9 +77,9 @@ Used internally by L<AnyEvent::FTP::Client>.
 
 =head1 AUTHOR
 
-author: Graham Ollis <plicease@cpan.org>
+Author: Graham Ollis E<lt>plicease@cpan.orgE<gt>
 
-contributors:
+Contributors:
 
 Ryo Okamoto
 
