@@ -2,12 +2,12 @@ package AnyEvent::FTP::Client::Role::StoreTransfer;
 
 use strict;
 use warnings;
-use v5.10;
+use 5.010;
 use Moo::Role;
 use warnings NONFATAL => 'all';
 
 # ABSTRACT: Store transfer interface for AnyEvent::FTP objects
-our $VERSION = '0.06'; # VERSION
+our $VERSION = '0.07'; # VERSION
 
 sub xfer
 {
@@ -93,13 +93,13 @@ AnyEvent::FTP::Client::Role::StoreTransfer - Store transfer interface for AnyEve
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 AUTHOR
 
-author: Graham Ollis <plicease@cpan.org>
+Author: Graham Ollis E<lt>plicease@cpan.orgE<gt>
 
-contributors:
+Contributors:
 
 Ryo Okamoto
 
