@@ -2,10 +2,10 @@ package AnyEvent::FTP::Client::Site;
 
 use strict;
 use warnings;
-use v5.10;
+use 5.010;
 
 # ABSTRACT: Dispatcher for site specific ftp commands
-our $VERSION = '0.06'; # VERSION
+our $VERSION = '0.07'; # VERSION
 
 sub new
 {
@@ -43,13 +43,13 @@ AnyEvent::FTP::Client::Site - Dispatcher for site specific ftp commands
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 AUTHOR
 
-author: Graham Ollis <plicease@cpan.org>
+Author: Graham Ollis E<lt>plicease@cpan.orgE<gt>
 
-contributors:
+Contributors:
 
 Ryo Okamoto
 
