@@ -2,13 +2,13 @@ package AnyEvent::FTP::Response;
 
 use strict;
 use warnings;
-use v5.10;
+use 5.010;
 use overload
   '""' => sub { shift->as_string },
   fallback => 1;
 
 # ABSTRACT: Response class for asynchronous ftp client
-our $VERSION = '0.06'; # VERSION
+our $VERSION = '0.07'; # VERSION
 
 
 sub new
@@ -51,7 +51,7 @@ AnyEvent::FTP::Response - Response class for asynchronous ftp client
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 DESCRIPTION
 
@@ -123,9 +123,9 @@ is the same as
 
 =head1 AUTHOR
 
-author: Graham Ollis <plicease@cpan.org>
+Author: Graham Ollis E<lt>plicease@cpan.orgE<gt>
 
-contributors:
+Contributors:
 
 Ryo Okamoto
 
