@@ -2,12 +2,12 @@ package AnyEvent::FTP::Role::Event;
 
 use strict;
 use warnings;
-use v5.10;
+use 5.010;
 use Moo::Role;
 use warnings NONFATAL => 'all';
 
 # ABSTRACT: Event interface for AnyEvent::FTP objects
-our $VERSION = '0.06'; # VERSION
+our $VERSION = '0.07'; # VERSION
 
 
 sub define_events
@@ -52,7 +52,7 @@ AnyEvent::FTP::Role::Event - Event interface for AnyEvent::FTP objects
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 SYNOPSIS
 
@@ -126,9 +126,9 @@ L<AnyEvent::FTP>
 
 =head1 AUTHOR
 
-author: Graham Ollis <plicease@cpan.org>
+Author: Graham Ollis E<lt>plicease@cpan.orgE<gt>
 
-contributors:
+Contributors:
 
 Ryo Okamoto
 
