@@ -2,12 +2,12 @@ package AnyEvent::FTP::Server::Context;
 
 use strict;
 use warnings;
-use v5.10;
+use 5.010;
 use Moo;
 use warnings NONFATAL => 'all';
 
 # ABSTRACT: FTP Server client context class
-our $VERSION = '0.06'; # VERSION
+our $VERSION = '0.07'; # VERSION
 
 with 'AnyEvent::FTP::Role::Event';
 with 'AnyEvent::FTP::Server::Role::Context';
@@ -112,7 +112,7 @@ AnyEvent::FTP::Server::Context - FTP Server client context class
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 METHODS
 
@@ -160,9 +160,9 @@ is used.
 
 =head1 AUTHOR
 
-author: Graham Ollis <plicease@cpan.org>
+Author: Graham Ollis E<lt>plicease@cpan.orgE<gt>
 
-contributors:
+Contributors:
 
 Ryo Okamoto
 
