@@ -2,12 +2,12 @@ package AnyEvent::FTP::Server::Role::ResponseEncoder;
 
 use strict;
 use warnings;
-use v5.10;
+use 5.010;
 use Moo::Role;
 use warnings NONFATAL => 'all';
 
 # ABSTRACT: Server response encoder role
-our $VERSION = '0.06'; # VERSION
+our $VERSION = '0.07'; # VERSION
 
 requires 'encode';
 requires 'new';
@@ -26,13 +26,13 @@ AnyEvent::FTP::Server::Role::ResponseEncoder - Server response encoder role
 
 =head1 VERSION
 
-version 0.06
+version 0.07
 
 =head1 AUTHOR
 
-author: Graham Ollis <plicease@cpan.org>
+Author: Graham Ollis E<lt>plicease@cpan.orgE<gt>
 
-contributors:
+Contributors:
 
 Ryo Okamoto
 
